//
//  kmpg
//
//  Copyright (C) 1997 Bjarni Ivarsson
//  email: Bjarni.Ivarsson@swipnet.se
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//

#ifndef FILEINFO_H
#define FILEINFO_H

#include <qdialog.h>
#include <qbttngrp.h>
#include <qpushbt.h>
#include <qlined.h>
#include <qcombo.h>
#include <qfile.h>
#include <kurl.h>

class Fileinfo 
{
   public:
      Fileinfo() { _is_ok = FALSE; };
      Fileinfo(KURL);
      ~Fileinfo();
      
      // Is the stream ok??
      int isOk();

      // General stream information
      QString getName();
      KURL getUrl() { return _url; };
      float getMsPerFrame();
      int getCopyright();
      int getOriginal();
      QString getVersion();
      QString getLayer();
      QString getFrequency();
      QString getMode();
      int getChannels();
      QString getBitrate();
      int getFramesize();
      int getMaxNumberOfFrames();
      int getMinNumberOfFrames();

      // ID3 related member functions
      bool isID3Ok() { return _id3_ok; };
      QString getID3Songname();
      QString getID3Artist();
      QString getID3Album();
      QString getID3Year();
      QString getID3Comment();
      unsigned char getID3Genre() { return (_id3_ok?_id3_genre:0); };
      bool isID3Settable();
      bool setID3Tag( QString, QString, QString, QString, QString, unsigned char );
   protected:
      void decodeHeader(unsigned long);
      void readID3(QFile*);
   private:
      KURL _url;
      QString _name;
      bool _is_ok;
      int _lsf, _mpeg25, _lay, _bitrate_index, _sampling_frequency;
      int _error_protection, _padding, _extension, _copyright, _original;
      int _emphasis, _mode, _mode_ext, _stereo;
      long _framesize, _filesize;
      
      bool _id3_ok;
      QString _id3_songname, _id3_artist, _id3_album, _id3_year, _id3_comment;
      unsigned char _id3_genre;
};


class FileinfoDlg : public QDialog
{
      Q_OBJECT
   public:
      FileinfoDlg( Fileinfo* );
      ~FileinfoDlg();
   private slots:
      void okPressed();
      void applyPressed();
   private:
      Fileinfo *_finfo;
      QButtonGroup *grp1, *grp2;
      QLineEdit *le[5];
      QComboBox *cbGenre;
      QPushButton *pbOk, *pbApply, *pbCancel;
};

#endif
